@@ -9,7 +9,15 @@
 namespace CustomCssEditor
 {
 
+void addGtkModule(const QString &moduleName);
+
+/**
+ * @note Make sure "colorreload-gtk-module" is added to the module list before calling this function
+ * @param colorsDefinitions a list of color definitions for GTK CSS
+ * @see GtkConfig::setColors
+ */
 void setColors(const QMap<QString, QColor> &colorsDefinitions);
+
 void setCustomClientSideDecorations(const QStringList &windowDecorationsButtonsImages);
 void disableCustomClientSideDecorations();
 
