@@ -10,10 +10,11 @@ namespace GSettingsEditor
 constinit unsigned s_applyId = 0;
 
 #if GLIB_CHECK_VERSION(2, 74, 0)
-void applySettings(void *)
+void
 #else
-int applySettings(void *)
+int
 #endif
+applySettings(void *)
 {
     g_settings_sync();
     s_applyId = 0;
@@ -39,15 +40,15 @@ void setValue(const char *paramName, const QVariant &paramValue, const char *cat
 
     g_autoptr(GSettings) gsettings = g_settings_new(category);
 
-    if (paramValue.type() == QVariant::Type::String) {
-        g_settings_set_string(gsettings, paramName, paramValue.toString().toUtf8().constData());
-    } else if (paramValue.type() == QVariant::Type::UInt) {
+    if (paramValue.typeId() == QMetaType::QString) {
+        g_settings_set_string(gsettings, paramName, get<QString>(paramValue).toUtf8().constData());
+    } else if (paramValue.typeId() == QMetaType::UInt) {
         g_settings_set_uint(gsettings, paramName, paramValue.toInt());
-    } else if (paramValue.type() == QVariant::Type::Int) {
+    } else if (paramValue.typeId() == QMetaType::Int) {
         g_settings_set_int(gsettings, paramName, paramValue.toInt());
-    } else if (paramValue.type() == QVariant::Type::Bool) {
+    } else if (paramValue.typeId() == QMetaType::Bool) {
         g_settings_set_boolean(gsettings, paramName, paramValue.toBool());
-    } else if (paramValue.type() == QVariant::Type::Double) {
+    } else if (paramValue.typeId() == QMetaType::Double) {
         g_settings_set_double(gsettings, paramName, paramValue.toDouble());
     }
 
