@@ -9,18 +9,27 @@
 #include <QRect>
 #include <QString>
 
+#include <KConfigGroup>
+#include <KSharedConfig>
+
 #include "auroraedecorationpainter.h"
 #include "standarddecorationpainter.h"
 
 const QRect DecorationPainter::ButtonGeometry{0, 0, 50, 50};
 
-std::unique_ptr<DecorationPainter> DecorationPainter::fromThemeName(const QString &themeName)
+std::unique_ptr<DecorationPainter> DecorationPainter::get()
 {
+    auto kwinConfig = KSharedConfig::openConfig(QStringLiteral("kwinrc"));
+    KConfigGroup decorationGroup = kwinConfig->group(QStringLiteral("org.kde.kdecoration2"));
+    const QString themeName = decorationGroup.readEntry(QStringLiteral("theme"), QStringLiteral("Breeze"));
+    const QString pluginName = decorationGroup.readEntry(QStringLiteral("library"), QStringLiteral("org.kde.breeze"));
+
+    // FIXME this does not work for Aurorae QML decorations
     static const QString auroraeThemePrefix = QStringLiteral("__aurorae__svg__");
     if (themeName.startsWith(auroraeThemePrefix)) {
         QString prefixlessThemeName = themeName.mid(auroraeThemePrefix.size());
         return std::unique_ptr<AuroraeDecorationPainter>{new AuroraeDecorationPainter(prefixlessThemeName)};
     } else {
-        return std::unique_ptr<StandardDecorationPainter>{new StandardDecorationPainter(themeName)};
+        return std::unique_ptr<StandardDecorationPainter>{new StandardDecorationPainter(pluginName)};
     }
 }
